@@ -1,26 +1,13 @@
 /*
-  Copyright (c) 2001 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
-  Copyright (C) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
-  Author: Kevin Krammer, krake@kdab.com
+  SPDX-FileCopyrightText: 2001 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileContributor: Kevin Krammer <krake@kdab.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
+  Marcus Bains line.
+  SPDX-FileCopyrightText: 2001 Ali Rahimi <ali@mit.edu>
 
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 #ifndef EVENTVIEWS_AGENDA_H
 #define EVENTVIEWS_AGENDA_H
@@ -117,7 +104,7 @@ public:
     Q_REQUIRED_RESULT int visibleContentsYMin() const;
     Q_REQUIRED_RESULT int visibleContentsYMax() const;
 
-    void setStartTime(const QTime &startHour);
+    void setStartTime(QTime startHour);
 
     AgendaItem::QPtr insertItem(const KCalendarCore::Incidence::Ptr &incidence, const QDateTime &recurrenceId, int X, int YTop, int YBottom, int itemPos, int itemCount, bool isSelected);
 
