@@ -1,28 +1,11 @@
 /*
-  Copyright (c) 2000,2001,2003 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2000, 2001, 2003 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 #include "agendaitem.h"
 #include "eventview.h"
-#include "viewcalendar.h"
 #include "helper.h"
 
 #include "prefs.h"
@@ -42,10 +25,10 @@
 #include <KLocalizedString>
 #include <KMessageBox>
 #include <KWordWrap>
-#include <KIconLoader>
 
 #include <QDragEnterEvent>
 #include <QPainter>
+#include <QPainterPath>
 #include <QPixmapCache>
 #include <QToolTip>
 #include <QMimeData>
@@ -74,8 +57,6 @@ AgendaItem::AgendaItem(EventView *eventView, const MultiViewCalendar::Ptr &calen
     , mCalendar(calendar)
     , mIncidence(item)
     , mOccurrenceDateTime(qd)
-    , mValid(true)
-    , mCloned(false)
     , mSelected(isSelected)
     , mSpecialEvent(false)
 {
@@ -1185,7 +1166,7 @@ bool AgendaItem::event(QEvent *event)
         if (!mEventView->preferences()->enableToolTips()) {
             return true;
         } else if (mValid) {
-            QHelpEvent *helpEvent = static_cast<QHelpEvent *>(event);
+            auto *helpEvent = static_cast<QHelpEvent *>(event);
             QToolTip::showText(
                 helpEvent->globalPos(),
                 KCalUtils::IncidenceFormatter::toolTipStr(
