@@ -1,32 +1,15 @@
 /*
-  Copyright (c) 2001 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
-  Copyright (C) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
-  Author: Kevin Krammer, krake@kdab.com
-  Author: Sergio Martins, sergio.martins@kdab.com
+  SPDX-FileCopyrightText: 2001 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileContributor: Kevin Krammer <krake@kdab.com>
+  SPDX-FileContributor: Sergio Martins <sergio@kdab.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 #include "agendaview.h"
 #include "agenda.h"
 #include "agendaitem.h"
-#include "viewcalendar.h"
 #include "alternatelabel.h"
 #include "calendardecoration.h"
 #include "decorationlabel.h"
@@ -75,13 +58,11 @@ enum {
 
 class Q_DECL_HIDDEN EventIndicator::Private
 {
-    EventIndicator *const q;
 
 public:
     Private(EventIndicator *parent, EventIndicator::Location loc)
-        : q(parent)
-        , mColumns(1)
-        , mLocation(loc)
+        : mLocation(loc)
+        , q(parent)
     {
         mEnabled.resize(mColumns);
 
@@ -114,10 +95,12 @@ public:
     }
 
 public:
-    int mColumns;
+    int mColumns = 1;
     Location mLocation;
     QPixmap mPixmap;
     QVector<bool> mEnabled;
+private:
+    EventIndicator *const q;
 };
 
 EventIndicator::EventIndicator(Location loc, QWidget *parent)
@@ -716,7 +699,7 @@ void AgendaView::Private::insertIncidence(const KCalendarCore::Incidence::Ptr &i
 
 ////////////////////////////////////////////////////////////////////////////
 
-AgendaView::AgendaView(const QDate &start, const QDate &end, bool isInteractive, bool isSideBySide, QWidget *parent)
+AgendaView::AgendaView(QDate start, QDate end, bool isInteractive, bool isSideBySide, QWidget *parent)
     : EventView(parent)
     , d(new Private(this, isInteractive, isSideBySide))
 {
@@ -731,7 +714,7 @@ AgendaView::AgendaView(const PrefsPtr &prefs, const QDate &start, const QDate &e
     init(start, end);
 }
 
-void AgendaView::init(const QDate &start, const QDate &end)
+void AgendaView::init(QDate start, QDate end)
 {
     d->mSelectedDates = Private::generateDateList(start, end);
 
@@ -766,19 +749,19 @@ void AgendaView::init(const QDate &start, const QDate &end)
     }
 
     // The widget itself
-    AgendaScrollArea *allDayScrollArea = new AgendaScrollArea(true, this, d->mIsInteractive,
+    auto *allDayScrollArea = new AgendaScrollArea(true, this, d->mIsInteractive,
                                                               d->mAllDayFrame);
     allDayFrameLayout->addWidget(allDayScrollArea);
     d->mAllDayAgenda = allDayScrollArea->agenda();
 
     /* Create the main agenda widget and the related widgets */
     QWidget *agendaFrame = new QWidget(d->mSplitterAgenda);
-    QHBoxLayout *agendaLayout = new QHBoxLayout(agendaFrame);
+    auto *agendaLayout = new QHBoxLayout(agendaFrame);
     agendaLayout->setContentsMargins(0, 0, 0, 0);
     agendaLayout->setSpacing(SPACING);
 
     // Create agenda
-    AgendaScrollArea *scrollArea = new AgendaScrollArea(false, this, d->mIsInteractive,
+    auto *scrollArea = new AgendaScrollArea(false, this, d->mIsInteractive,
                                                         agendaFrame);
     d->mAgenda = scrollArea->agenda();
 
@@ -791,7 +774,7 @@ void AgendaView::init(const QDate &start, const QDate &end)
 
     // This timeLabelsZoneLayout is for adding some spacing
     // to align timelabels, to agenda's grid
-    QVBoxLayout *timeLabelsZoneLayout = new QVBoxLayout();
+    auto *timeLabelsZoneLayout = new QVBoxLayout();
 
     agendaLayout->addLayout(timeLabelsZoneLayout);
     agendaLayout->addWidget(scrollArea);
@@ -1069,7 +1052,7 @@ void AgendaView::zoomView(const int delta, const QPoint &pos, const Qt::Orientat
 {
     // TODO find out why this is necessary. seems to be some kind of performance hack
     static QDate zoomDate;
-    static QTimer *t = new QTimer(this);
+    static auto *t = new QTimer(this);
 
     //Zoom to the selected incidence, on the other way
     // zoom to the date on screen after the first mousewheel move.
@@ -1147,7 +1130,7 @@ void AgendaView::placeDecorations(DecorationList &decoList, const QDate &date, Q
             decoHBox->setMinimumWidth(1);
 
             for (CalendarDecoration::Element *it : elements) {
-                DecorationLabel *label = new DecorationLabel(it, decoHBox);
+                auto *label = new DecorationLabel(it, decoHBox);
                 label->setAlignment(Qt::AlignBottom);
                 label->setMinimumWidth(1);
                 layout->addWidget(label);
@@ -1182,7 +1165,7 @@ void AgendaView::createDayLabels(bool force)
     d->mLayoutTopDayLabels->setSpacing(1);
 
     // this spacer moves the day labels over to line up with the day columns
-    QSpacerItem *spacer
+    auto *spacer
         = new QSpacerItem((!d->mIsSideBySide ? d->mTimeLabelsZone->width() : 0)
                           +SPACING
                           +d->mAllDayAgenda->scrollArea()->frameWidth(),
@@ -1241,7 +1224,7 @@ void AgendaView::createDayLabels(bool force)
                                 date.day());
         QString shortstr = QString::number(date.day());
 
-        AlternateLabel *dayLabel
+        auto *dayLabel
             = new AlternateLabel(shortstr, longstr, veryLongStr, topDayLabelBox);
         topDayLabelBoxLayout->addWidget(dayLabel);
         dayLabel->useShortText(); // will be recalculated in updateDayLabelSizes() anyway
@@ -1270,7 +1253,7 @@ void AgendaView::createDayLabels(bool force)
 #endif
     }
 
-    QSpacerItem *rightSpacer = new QSpacerItem(d->mAllDayAgenda->scrollArea()->frameWidth(),
+    auto *rightSpacer = new QSpacerItem(d->mAllDayAgenda->scrollArea()->frameWidth(),
                                                1, QSizePolicy::Fixed);
     d->mLayoutTopDayLabels->addSpacerItem(rightSpacer);
 
@@ -1437,7 +1420,7 @@ void AgendaView::createTimeBarHeaders()
 
     const auto lst = d->mTimeLabelsZone->timeLabels();
     for (QScrollArea *area : lst) {
-        TimeLabels *timeLabel = static_cast<TimeLabels *>(area->widget());
+        auto *timeLabel = static_cast<TimeLabels *>(area->widget());
         QLabel *label
             = new QLabel(timeLabel->header().replace(QLatin1Char('/'), QStringLiteral("/ ")),
                          d->mTimeBarHeaderFrame);
@@ -1515,7 +1498,6 @@ void AgendaView::updateEventDates(AgendaItem *item, bool addIncidence, Akonadi::
     }
 
     int daysLength = 0;
-    //  startDt.setDate(startDate);
 
     KCalendarCore::Incidence::Ptr incidence = item->incidence();
     Akonadi::Item aitem = d->mViewCalendar->item(incidence);
@@ -1575,33 +1557,6 @@ void AgendaView::updateEventDates(AgendaItem *item, bool addIncidence, Akonadi::
             QTimer::singleShot(0, this, &AgendaView::updateView);
             return;
         }
-    } else if (const KCalendarCore::Todo::Ptr td = CalendarSupport::todo(incidence)) {
-        startDt = td->hasStartDate() ? td->dtStart() : td->dtDue();
-        // convert to calendar timespec because we then manipulate it with time coming from
-        // the calendar
-        startDt = startDt.toLocalTime();
-        startDt.setDate(thisDate.addDays(td->dtDue().daysTo(startDt)));
-        if (!td->allDay()) {
-            startDt.setTime(startTime);
-        }
-
-        endDt = startDt;
-        endDt.setDate(thisDate);
-        if (!td->allDay()) {
-            endDt.setTime(endTime);
-        }
-
-        if (td->dtDue().toLocalTime() == endDt) {
-            // No change
-            QMetaObject::invokeMethod(this, &AgendaView::updateView, Qt::QueuedConnection);
-            return;
-        }
-    }
-
-    // A commented code block which had 150 lines to adjust recurrence was here.
-    // I deleted it in rev 1180272 to make this function readable.
-
-    if (const KCalendarCore::Event::Ptr ev = CalendarSupport::event(incidence)) {
         /* setDtEnd() must be called before setDtStart(), otherwise, when moving
          * events, CalendarLocal::incidenceUpdated() will not remove the old hash
          * and that causes the event to be shown in the old date also (bug #179157).
@@ -1612,10 +1567,24 @@ void AgendaView::updateEventDates(AgendaItem *item, bool addIncidence, Akonadi::
             endDt.toTimeSpec(incidence->dateTime(KCalendarCore::Incidence::RoleEnd).timeSpec()));
         incidence->setDtStart(startDt.toTimeSpec(incidence->dtStart().timeSpec()));
     } else if (const KCalendarCore::Todo::Ptr td = CalendarSupport::todo(incidence)) {
+        endDt = td->dtDue(true).toLocalTime().addDays(daysOffset);
+        endDt.setTime(td->allDay() ? QTime(00, 00, 00) : endTime);
+
+        if (td->dtDue(true).toLocalTime() == endDt) {
+            // No change
+            QMetaObject::invokeMethod(this, &AgendaView::updateView, Qt::QueuedConnection);
+            return;
+        }
+
+        const auto shift = td->dtDue(true).secsTo(endDt);
+        startDt = td->dtStart(true).addSecs(shift);
         if (td->hasStartDate()) {
             td->setDtStart(startDt.toTimeSpec(incidence->dtStart().timeSpec()));
         }
-        td->setDtDue(endDt.toTimeSpec(td->dtDue().timeSpec()));
+        if (td->recurs()) {
+            td->setDtRecurrence(td->dtRecurrence().addSecs(shift));
+        }
+        td->setDtDue(endDt.toTimeSpec(td->dtDue().timeSpec()), true);
     }
 
     if (!incidence->hasRecurrenceId()) {
@@ -2165,7 +2134,7 @@ void AgendaView::setHolidayMasks()
 
     d->mHolidayMask.resize(d->mSelectedDates.count() + 1);
 
-    const QList<QDate> workDays = CalendarSupport::workDays(d->mSelectedDates.first().addDays(-1),
+    const QList<QDate> workDays = CalendarSupport::workDays(d->mSelectedDates.constFirst().addDays(-1),
                                                             d->mSelectedDates.last());
     for (int i = 0; i < d->mSelectedDates.count(); ++i) {
         d->mHolidayMask[i] = !workDays.contains(d->mSelectedDates[ i ]);
