@@ -1,25 +1,10 @@
 /*
-  Copyright (c) 2007 Loïc Corbasson <loic.corbasson@gmail.com>
+  SPDX-FileCopyrightText: 2007 Loïc Corbasson <loic.corbasson@gmail.com>
 
-  This library is free software; you can redistribute it and/or
-  modify it under the terms of the GNU Library General Public
-  License as published by the Free Software Foundation; either
-  version 2 of the License, or (at your option) any later version.
-
-  This library is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  Library General Public License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to
-  the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-  Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 #include "calendardecoration.h"
 
-#include <QDate>
-
 using namespace EventViews::CalendarDecoration;
 
 Element::Element(const QString &id)
@@ -73,26 +58,29 @@ StoredElement::StoredElement(const QString &id) : Element(id)
 }
 
 StoredElement::StoredElement(const QString &id, const QString &shortText)
-    : Element(id), mShortText(shortText)
+    : Element(id)
+    , mShortText(shortText)
 {
 }
 
-StoredElement::StoredElement(const QString &id, const QString &shortText,
-                             const QString &longText)
-    : Element(id), mShortText(shortText), mLongText(longText)
+StoredElement::StoredElement(const QString &id, const QString &shortText, const QString &longText)
+    : Element(id)
+    , mShortText(shortText)
+    , mLongText(longText)
 {
 }
 
-StoredElement::StoredElement(const QString &id, const QString &shortText,
-                             const QString &longText,
-                             const QString &extensiveText)
-    : Element(id), mShortText(shortText), mLongText(longText),
-      mExtensiveText(extensiveText)
+StoredElement::StoredElement(const QString &id, const QString &shortText, const QString &longText, const QString &extensiveText)
+    : Element(id)
+    , mShortText(shortText)
+    , mLongText(longText)
+    , mExtensiveText(extensiveText)
 {
 }
 
 StoredElement::StoredElement(const QString &id, const QPixmap &pixmap)
-    : Element(id), mPixmap(pixmap)
+    : Element(id)
+    , mPixmap(pixmap)
 {
 }
 
@@ -154,6 +142,8 @@ Decoration::Decoration()
 
 Decoration::~Decoration()
 {
+    //Deleted by label directly.
+#if 0
     for (Element::List lst : qAsConst(mDayElements)) {
         qDeleteAll(lst);
         lst.clear();
@@ -170,6 +160,7 @@ Decoration::~Decoration()
         qDeleteAll(lst);
         lst.clear();
     }
+#endif
     mDayElements.clear();
     mWeekElements.clear();
     mMonthElements.clear();
@@ -282,4 +273,3 @@ QDate Decoration::yearDate(const QDate &date)
 {
     return QDate(date.year(), 1, 1);
 }
-
