@@ -1,23 +1,7 @@
 /*
-  Copyright (c) 2007 Bruno Virlet <bruno@virlet.org>
+  SPDX-FileCopyrightText: 2007 Bruno Virlet <bruno@virlet.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 #include "timelabelszone.h"
 #include "agenda.h"
@@ -68,7 +52,8 @@ void TimeLabelsZone::init()
 
     addTimeLabels(mPrefs->timeZone());
 
-    foreach (const QString &zoneStr, mPrefs->timeScaleTimezones()) {
+    const auto lst = mPrefs->timeScaleTimezones();
+    for (const QString &zoneStr : lst) {
         if (!seenTimeZones.contains(zoneStr)) {
             auto zone = QTimeZone(zoneStr.toUtf8());
             if (zone.isValid()) {
@@ -81,8 +66,8 @@ void TimeLabelsZone::init()
 
 void TimeLabelsZone::addTimeLabels(const QTimeZone &zone)
 {
-    QScrollArea *area = new QScrollArea(this);
-    TimeLabels *labels = new TimeLabels(zone, 24, this);
+    auto *area = new QScrollArea(this);
+    auto *labels = new TimeLabels(zone, 24, this);
     mTimeLabelsList.prepend(area);
     area->setWidgetResizable(true);
     area->setWidget(labels);
@@ -109,7 +94,7 @@ void TimeLabelsZone::setupTimeLabel(QScrollArea *area)
         area->verticalScrollBar()->setValue(mAgenda->verticalScrollBar()->value());
     }
 
-    TimeLabels *timeLabels = static_cast<TimeLabels *>(area->widget());
+    auto *timeLabels = static_cast<TimeLabels *>(area->widget());
     timeLabels->setAgenda(mAgenda);
 
     // timelabel's scroll is just a slave, this shouldn't be here
@@ -131,7 +116,7 @@ int TimeLabelsZone::preferedTimeLabelsWidth() const
 void TimeLabelsZone::updateAll()
 {
     for (QScrollArea *area : qAsConst(mTimeLabelsList)) {
-        TimeLabels *timeLabel = static_cast<TimeLabels *>(area->widget());
+        auto *timeLabel = static_cast<TimeLabels *>(area->widget());
         timeLabel->updateConfig();
     }
 }
@@ -154,8 +139,9 @@ void TimeLabelsZone::setAgendaView(AgendaView *agendaView)
 void TimeLabelsZone::updateTimeLabelsPosition()
 {
     if (mAgenda) {
-        foreach (QScrollArea *area, timeLabels()) {
-            TimeLabels *label = static_cast<TimeLabels *>(area->widget());
+        const auto lst = timeLabels();
+        for (QScrollArea *area : lst) {
+            auto *label = static_cast<TimeLabels *>(area->widget());
             const int adjustment = mAgenda->contentsY();
             // y() is the offset to our parent (QScrollArea)
             // and gets negative as we scroll
