@@ -1,27 +1,11 @@
 /*
-  Copyright (c) 2000,2001 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (C) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
-  Copyright (C) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
-  Author: Kevin Krammer, krake@kdab.com
-  Author: Sergio Martins, sergio.martins@kdab.com
+  SPDX-FileCopyrightText: 2000, 2001 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileContributor: Kevin Krammer <krake@kdab.com>
+  SPDX-FileContributor: Sergio Martins <sergio@kdab.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 #ifndef EVENTVIEWS_EVENTVIEW_P_H
 #define EVENTVIEWS_EVENTVIEW_P_H
@@ -54,8 +38,8 @@ public: // virtual functions
 
 public: /// Members
     Akonadi::ETMCalendar::Ptr calendar;
-    CalendarSupport::CollectionSelection *customCollectionSelection;
-    KCheckableProxyModel *collectionSelectionModel;
+    CalendarSupport::CollectionSelection *customCollectionSelection = nullptr;
+    KCheckableProxyModel *collectionSelectionModel = nullptr;
 
     QByteArray identifier;
     QDateTime startDateTime;
@@ -67,9 +51,9 @@ public: /// Members
      * we will only show a new event dialog if we previously received a
      * key_Return press, otherwise a new event dialog appears when
      * you hit return in some yes/no dialog */
-    bool mReturnPressed;
-    bool mDateRangeSelectionEnabled;
-    bool mTypeAhead;
+    bool mReturnPressed = false;
+    bool mDateRangeSelectionEnabled = true;
+    bool mTypeAhead = false;
     QObject *mTypeAheadReceiver = nullptr;
     QList<QEvent *> mTypeAheadEvents;
     static CalendarSupport::CollectionSelection *sGlobalCollectionSelection;
