@@ -1,27 +1,11 @@
 /*
-  Copyright (c) 1999 Preston Brown <pbrown@kde.org>
-  Copyright (c) 2000,2001 Cornelius Schumacher <schumacher@kde.org>
-  Copyright (c) 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
-  Copyright (c) 2010 Sérgio Martins <iamsergio@gmail.com>
-  Copyright (c) 2012-2013 Allen Winter <winter@kde.org>
+  SPDX-FileCopyrightText: 1999 Preston Brown <pbrown@kde.org>
+  SPDX-FileCopyrightText: 2000, 2001 Cornelius Schumacher <schumacher@kde.org>
+  SPDX-FileCopyrightText: 2003-2004 Reinhold Kainhofer <reinhold@kainhofer.com>
+  SPDX-FileCopyrightText: 2010 Sérgio Martins <iamsergio@gmail.com>
+  SPDX-FileCopyrightText: 2012-2013 Allen Winter <winter@kde.org>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 //TODO: put a reminder and/or recurs icon on the item?
@@ -59,6 +43,9 @@ enum {
     Dummy_EOF_Column // Dummy enum value for iteration purposes only. Always keep at the end.
 };
 
+static const QTime DAY_START {00, 00};
+static const QTime DAY_END   {23, 59, 59, 999};
+
 static QString cleanSummary(const QString &summary, const QDateTime &next)
 {
     QString retStr = summary;
@@ -84,7 +71,7 @@ public:
 
     bool operator<(const QTreeWidgetItem &other) const override;
 
-    const QTreeWidget *mTreeWidget = nullptr;
+    QTreeWidget *const mTreeWidget;
     const Akonadi::Item mIncidence;
     QDateTime start;
     QDateTime end;
@@ -92,21 +79,15 @@ public:
 
 bool ListViewItem::operator<(const QTreeWidgetItem &other) const
 {
-    const ListViewItem *otheritem = static_cast<const ListViewItem *>(&other);
+    const auto *otheritem = static_cast<const ListViewItem *>(&other);
 
     switch (treeWidget()->sortColumn()) {
     case StartDateTime_Column:
-        return otheritem->start < start;
+        // Missing start times are sorted before any defined time.
+        return otheritem->start.isValid() && (!start.isValid() || start < otheritem->start);
     case EndDateTime_Column:
-    {
-        Incidence::Ptr thisInc = CalendarSupport::incidence(mIncidence);
-        const auto thisEnd = thisInc->dateTime(Incidence::RoleEnd).toLocalTime();
-
-        Incidence::Ptr otherInc = CalendarSupport::incidence(otheritem->mIncidence);
-        const auto otherEnd = otherInc->dateTime(Incidence::RoleEnd).toLocalTime();
-
-        return otherEnd < thisEnd;
-    }
+        // Missing end times are sorted after any defined time.
+        return end.isValid() && (!otheritem->end.isValid() || end < otheritem->end);
     default:
         return QTreeWidgetItem::operator <(other);
     }
@@ -184,20 +165,23 @@ bool ListView::Private::ListItemVisitor::visit(const Event::Ptr &e)
     mItem->setIcon(Summary_Column, eventPxmp);
 
     QDateTime next;
-    mItem->start = e->dtStart().toLocalTime();
-    mItem->end = e->dtEnd().toLocalTime();
     if (e->recurs()) {
         const qint64 duration = e->dtStart().secsTo(e->dtEnd());
-        QDateTime kdt(mStartDate, QTime(0, 0, 0));
-        kdt = kdt.addSecs(-1);
+        QDateTime kdt(mStartDate, DAY_START);
+        kdt = kdt.addMSecs(-1);
         mItem->start = e->recurrence()->getNextDateTime(kdt).toLocalTime();
         mItem->end = mItem->start.addSecs(duration);
         next = e->recurrence()->getNextDateTime(mItem->start).toLocalTime();
+    } else {
+        mItem->start = e->dtStart().toLocalTime();
+        mItem->end = e->dtEnd().toLocalTime();
     }
 
     mItem->setText(Summary_Column, cleanSummary(e->summary(), next));
 
     if (e->allDay()) {
+        mItem->start.setTime(DAY_START);
+        mItem->end.setTime(DAY_END);
         mItem->setText(StartDateTime_Column,
                        QLocale().toString(mItem->start.date(), QLocale::ShortFormat));
         mItem->setText(EndDateTime_Column,
@@ -217,6 +201,25 @@ bool ListView::Private::ListItemVisitor::visit(const Todo::Ptr &t)
 {
     mItem->setIcon(Summary_Column, QIcon::fromTheme(t->iconName()));
 
+    if (t->recurs()) {
+        QDateTime kdt(mStartDate, DAY_START);
+        kdt = kdt.addMSecs(-1);
+        mItem->start = t->recurrence()->getNextDateTime(kdt).toLocalTime();
+        if (t->hasDueDate()) {
+            const qint64 duration = t->dtStart().secsTo(t->dtDue());
+            mItem->end = mItem->start.addSecs(duration);
+        } else {
+            mItem->end = QDateTime();
+        }
+    } else {
+        mItem->start = t->hasStartDate() ? t->dtStart().toLocalTime() : QDateTime();
+        mItem->end = t->hasDueDate() ? t->dtDue().toLocalTime() : QDateTime();
+    }
+    if (t->allDay()) {
+        mItem->start.setTime(DAY_START);
+        mItem->end.setTime(DAY_END);
+    }
+
     mItem->setText(Summary_Column, cleanSummary(t->summary(), QDateTime()));
 
     if (t->hasStartDate()) {
@@ -252,6 +255,10 @@ bool ListView::Private::ListItemVisitor::visit(const Todo::Ptr &t)
 bool ListView::Private::ListItemVisitor::visit(const Journal::Ptr &j)
 {
     mItem->setIcon(Summary_Column, QIcon::fromTheme(j->iconName()));
+
+    mItem->start = j->dtStart();
+    mItem->end = QDateTime();
+
     if (j->summary().isEmpty()) {
         mItem->setText(Summary_Column,
                        cleanSummary(j->description().section(QLatin1Char('\n'), 0, 0),
@@ -260,12 +267,15 @@ bool ListView::Private::ListItemVisitor::visit(const Journal::Ptr &j)
         mItem->setText(Summary_Column, cleanSummary(j->summary(), QDateTime()));
     }
     if (j->allDay()) {
+        mItem->start.setTime(DAY_START);
         mItem->setText(StartDateTime_Column,
                        QLocale().toString(j->dtStart().toLocalTime().date(), QLocale::ShortFormat));
     } else {
         mItem->setText(StartDateTime_Column,
                        QLocale().toString(j->dtStart().toLocalTime(), QLocale::ShortFormat));
     }
+    mItem->setText(EndDateTime_Column, QStringLiteral("---"));
+    mItem->setText(Categories_Column, j->categoriesStr());
 
     return true;
 }
@@ -324,7 +334,7 @@ Akonadi::Item::List ListView::selectedIncidences() const
     QTreeWidgetItem *item = d->mTreeWidget->selectedItems().isEmpty() ? nullptr
                             : d->mTreeWidget->selectedItems().first();
     if (item) {
-        ListViewItem *i = static_cast<ListViewItem *>(item);
+        auto *i = static_cast<ListViewItem *>(item);
         eventList.append(i->mIncidence);
     }
     return eventList;
@@ -347,7 +357,7 @@ void ListView::updateView()
     for (int col = StartDateTime_Column; col < Dummy_EOF_Column; ++col) {
         d->mTreeWidget->resizeColumnToContents(col);
     }
-    d->mTreeWidget->sortItems(StartDateTime_Column, Qt::DescendingOrder);
+    d->mTreeWidget->sortItems(StartDateTime_Column, Qt::AscendingOrder);
 }
 
 void ListView::showDates(const QDate &start, const QDate &end, const QDate &preferredMonth)
@@ -427,7 +437,7 @@ void ListView::Private::addIncidence(const Akonadi::ETMCalendar::Ptr &calendar,
             tinc->setReadOnly(true);
         }
     }
-    ListViewItem *item = new ListViewItem(aitem, mTreeWidget);
+    auto *item = new ListViewItem(aitem, mTreeWidget);
 
     // set tooltips
     for (int col = 0; col < Dummy_EOF_Column; ++col) {
@@ -461,8 +471,8 @@ void ListView::changeIncidenceDisplay(const Akonadi::Item &aitem, int action)
 {
     const Incidence::Ptr incidence = CalendarSupport::incidence(aitem);
     ListViewItem *item = nullptr;
-    QDate f = d->mSelectedDates.first();
-    QDate l = d->mSelectedDates.last();
+    const QDate f = d->mSelectedDates.constFirst();
+    const QDate l = d->mSelectedDates.constLast();
 
     QDate date;
     if (CalendarSupport::hasTodo(aitem)) {
@@ -501,7 +511,7 @@ ListViewItem *ListView::Private::getItemForIncidence(const Akonadi::Item &aitem)
 {
     int index = 0;
     while (QTreeWidgetItem *it = mTreeWidget->topLevelItem(index)) {
-        ListViewItem *item = static_cast<ListViewItem *>(it);
+        auto *item = static_cast<ListViewItem *>(it);
         if (item->mIncidence.id() == aitem.id()) {
             return item;
         }
