@@ -1,23 +1,7 @@
 /*
-  Copyright (c) 2008 Bruno Virlet <bruno.virlet@gmail.com>
+  SPDX-FileCopyrightText: 2008 Bruno Virlet <bruno.virlet@gmail.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
-
-  As a special exception, permission is given to link this program
-  with any edition of Qt, and distribute the resulting executable,
-  without including the source code for Qt in the source distribution.
+  SPDX-License-Identifier: GPL-2.0-or-later WITH Qt-Commercial-exception-1.0
 */
 
 #ifndef EVENTVIEWS_MONTHSCENE_H
@@ -32,14 +16,11 @@
 #include <QGraphicsView>
 #include <QMap>
 
-namespace Akonadi
-{
+namespace Akonadi {
 class IncidenceChanger;
 }
 
-namespace EventViews
-{
-
+namespace EventViews {
 class MonthCell;
 class MonthItem;
 class MonthView;
@@ -62,32 +43,35 @@ public:
     };
 
     explicit MonthScene(MonthView *parent);
-    ~MonthScene();
+    ~MonthScene() override;
 
-    int columnWidth() const;
-    int rowHeight() const;
+    Q_REQUIRED_RESULT int columnWidth() const;
+    Q_REQUIRED_RESULT int rowHeight() const;
 
     MonthCell *firstCellForMonthItem(MonthItem *manager);
-    int height(MonthItem *manager);
-    int itemHeight();
-    int itemHeightIncludingSpacing();
+    Q_REQUIRED_RESULT int height(MonthItem *manager);
+    Q_REQUIRED_RESULT int itemHeight();
+    Q_REQUIRED_RESULT int itemHeightIncludingSpacing();
     QList<MonthItem *> mManagerList;
-    MonthView *mMonthView;
+    MonthView *mMonthView = nullptr;
 
     MonthView *monthView() const
     {
         return mMonthView;
     }
+
     QMap<QDate, MonthCell *> mMonthCellMap;
 
-    bool initialized()
+    Q_REQUIRED_RESULT bool initialized() const
     {
         return mInitialized;
     }
+
     void setInitialized(bool i)
     {
         mInitialized = i;
     }
+
     void resetAll();
     Akonadi::IncidenceChanger *incidenceChanger() const;
 
@@ -97,12 +81,12 @@ public:
      * Returns the vertical position where the top of the cell should be
      * painted taking in account margins, rowHeight
      */
-    int cellVerticalPos(const MonthCell *cell) const;
+    Q_REQUIRED_RESULT int cellVerticalPos(const MonthCell *cell) const;
 
     /**
      * Idem, for the horizontal position
      */
-    int cellHorizontalPos(const MonthCell *cell) const;
+    Q_REQUIRED_RESULT int cellHorizontalPos(const MonthCell *cell) const;
 
     /**
       Select item. If the argument is 0, the currently selected item gets
@@ -110,7 +94,7 @@ public:
       about selection/deselection of events.
     */
     void selectItem(MonthItem *);
-    int maxRowCount();
+    Q_REQUIRED_RESULT int maxRowCount();
 
     MonthCell *selectedCell() const;
     MonthCell *previousCell() const;
@@ -118,17 +102,17 @@ public:
     /**
       Get the space on the right of the cell associated to the date @p date.
     */
-    int getRightSpan(const QDate &date) const;
+    Q_REQUIRED_RESULT int getRightSpan(QDate date) const;
 
     /**
       Get the space on the left of the cell associated to the date @p date.
     */
-    int getLeftSpan(const QDate &date) const;
+    Q_REQUIRED_RESULT int getLeftSpan(QDate date) const;
 
     /**
       Returns the date in the first column of the row given by @p row.
     */
-    QDate firstDateOnRow(int row) const;
+    Q_REQUIRED_RESULT QDate firstDateOnRow(int row) const;
 
     /**
       Calls updateGeometry() on each MonthItem
@@ -140,7 +124,7 @@ public:
 
       @see MonthItem::height()
     */
-    int startHeight()
+    Q_REQUIRED_RESULT int startHeight() const
     {
         return mStartHeight;
     }
@@ -158,7 +142,7 @@ public:
     /**
       Returns the resize type.
     */
-    ResizeType resizeType()
+    Q_REQUIRED_RESULT ResizeType resizeType() const
     {
         return mResizeType;
     }
@@ -171,31 +155,37 @@ public:
         return mSelectedItem;
     }
 
-    QPixmap birthdayPixmap() const
+    Q_REQUIRED_RESULT QPixmap birthdayPixmap() const
     {
         return mBirthdayPixmap;
     }
-    QPixmap anniversaryPixmap() const
+
+    Q_REQUIRED_RESULT QPixmap anniversaryPixmap() const
     {
         return mAnniversaryPixmap;
     }
-    QPixmap alarmPixmap() const
+
+    Q_REQUIRED_RESULT QPixmap alarmPixmap() const
     {
         return mAlarmPixmap;
     }
-    QPixmap recurPixmap() const
+
+    Q_REQUIRED_RESULT QPixmap recurPixmap() const
     {
         return mRecurPixmap;
     }
-    QPixmap readonlyPixmap() const
+
+    Q_REQUIRED_RESULT QPixmap readonlyPixmap() const
     {
         return mReadonlyPixmap;
     }
-    QPixmap replyPixmap() const
+
+    Q_REQUIRED_RESULT QPixmap replyPixmap() const
     {
-        return  mReplyPixmap;
+        return mReplyPixmap;
     }
-    QPixmap holidayPixmap() const
+
+    Q_REQUIRED_RESULT QPixmap holidayPixmap() const
     {
         return mHolidayPixmap;
     }
@@ -284,14 +274,14 @@ private:
     bool mInitialized;
 
     // User interaction.
-    MonthItem *mClickedItem; // todo ini in ctor
-    MonthItem *mActionItem;
+    MonthItem *mClickedItem = nullptr; // todo ini in ctor
+    MonthItem *mActionItem = nullptr;
     bool mActionInitiated;
 
-    MonthItem *mSelectedItem;
+    MonthItem *mSelectedItem = nullptr;
     QDate mSelectedCellDate;
-    MonthCell *mStartCell; // start cell when dragging
-    MonthCell *mPreviousCell; // the cell before that one during dragging
+    MonthCell *mStartCell = nullptr; // start cell when dragging
+    MonthCell *mPreviousCell = nullptr; // the cell before that one during dragging
 
     ActionType mActionType;
     ResizeType mResizeType;
@@ -313,7 +303,7 @@ private:
     QPixmap mReplyPixmap;
     QPixmap mHolidayPixmap;
     QBasicTimer repeatTimer;
-    ScrollIndicator *mCurrentIndicator;
+    ScrollIndicator *mCurrentIndicator = nullptr;
     friend class MonthGraphicsView;
 };
 
@@ -342,10 +332,9 @@ protected:
     void resizeEvent(QResizeEvent *) override;
 
 private:
-    MonthScene *mScene;
-    MonthView *mMonthView;
+    MonthScene *mScene = nullptr;
+    MonthView *mMonthView = nullptr;
 };
-
 }
 
 #endif
