@@ -1,21 +1,9 @@
 /*
-  Copyright (c) 2007 Volker Krause <vkrause@kde.org>
-  Copyright (C) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.net
-  Author: Sergio Martins <sergio.martins@kdab.com>
+  SPDX-FileCopyrightText: 2007 Volker Krause <vkrause@kde.org>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.net>
+  SPDX-FileContributor: Sergio Martins <sergio.martins@kdab.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 #include "multiagendaview.h"
 
@@ -105,16 +93,12 @@ private:
         void paintEvent(QPaintEvent *event) override;
 
     private:
-        QString mText;
+        const QString mText;
     };
 
 public:
     Private(MultiAgendaView *qq)
         : q(qq)
-        , mUpdateOnShow(true)
-        , mPendingChanges(true)
-        , mCustomColumnSetupUsed(false)
-        , mCustomNumberOfColumns(2)
     {
     }
 
@@ -130,7 +114,7 @@ public:
     void setupViews();
     void resizeScrollView(const QSize &size);
 
-    MultiAgendaView *q;
+    MultiAgendaView *const q;
     QList<AgendaView *> mAgendaViews;
     QList<QWidget *> mAgendaWidgets;
     QWidget *mTopBox = nullptr;
@@ -142,12 +126,12 @@ public:
     QWidget *mLeftBottomSpacer = nullptr;
     QWidget *mRightBottomSpacer = nullptr;
     QDate mStartDate, mEndDate;
-    bool mUpdateOnShow;
-    bool mPendingChanges;
-    bool mCustomColumnSetupUsed;
+    bool mUpdateOnShow = true;
+    bool mPendingChanges = true;
+    bool mCustomColumnSetupUsed = false;
     QVector<KCheckableProxyModel *> mCollectionSelectionModels;
     QStringList mCustomColumnTitles;
-    int mCustomNumberOfColumns;
+    int mCustomNumberOfColumns = 2;
     QLabel *mLabel = nullptr;
     QWidget *mRightDummyWidget = nullptr;
     QHash<QString, KViewStateMaintainer<ETMViewStateSaver> * > mSelectionSavers;
@@ -157,7 +141,7 @@ MultiAgendaView::MultiAgendaView(QWidget *parent)
     : EventView(parent)
     , d(new Private(this))
 {
-    QHBoxLayout *topLevelLayout = new QHBoxLayout(this);
+    auto *topLevelLayout = new QHBoxLayout(this);
     topLevelLayout->setSpacing(0);
     topLevelLayout->setContentsMargins(0, 0, 0, 0);
 
@@ -165,7 +149,7 @@ MultiAgendaView::MultiAgendaView(QWidget *parent)
     int topLabelHeight = 2 * fm.height() + fm.lineSpacing();
 
     QWidget *topSideBox = new QWidget(this);
-    QVBoxLayout *topSideBoxVBoxLayout = new QVBoxLayout(topSideBox);
+    auto *topSideBoxVBoxLayout = new QVBoxLayout(topSideBox);
     topSideBoxVBoxLayout->setContentsMargins(0, 0, 0, 0);
 
     QWidget *topSideSpacer = new QWidget(topSideBox);
@@ -180,7 +164,7 @@ MultiAgendaView::MultiAgendaView(QWidget *parent)
     d->mLabel->setWordWrap(true);
 
     QWidget *sideBox = new QWidget(d->mLeftSplitter);
-    QVBoxLayout *sideBoxVBoxLayout = new QVBoxLayout(sideBox);
+    auto *sideBoxVBoxLayout = new QVBoxLayout(sideBox);
     sideBoxVBoxLayout->setContentsMargins(0, 0, 0, 0);
 
     // compensate for the frame the agenda views but not the timelabels have
@@ -211,7 +195,7 @@ MultiAgendaView::MultiAgendaView(QWidget *parent)
     d->mScrollArea->setFrameShape(QFrame::NoFrame);
     topLevelLayout->addWidget(d->mScrollArea, 100);
     d->mTopBox = new QWidget(d->mScrollArea->viewport());
-    QHBoxLayout *mTopBoxHBoxLayout = new QHBoxLayout(d->mTopBox);
+    auto *mTopBoxHBoxLayout = new QHBoxLayout(d->mTopBox);
     mTopBoxHBoxLayout->setContentsMargins(0, 0, 0, 0);
     d->mScrollArea->setWidget(d->mTopBox);
 
@@ -272,7 +256,7 @@ void MultiAgendaView::recreateViews()
     } else {
         const auto lst = collectionSelection()->selectedCollections();
         for (const Akonadi::Collection &i : lst) {
-            if (i.contentMimeTypes().contains(KCalCore::Event::eventMimeType())) {
+            if (i.contentMimeTypes().contains(KCalendarCore::Event::eventMimeType())) {
                 d->addView(i);
             }
         }
@@ -399,9 +383,9 @@ Akonadi::Item::List MultiAgendaView::selectedIncidences() const
     return list;
 }
 
-KCalCore::DateList MultiAgendaView::selectedIncidenceDates() const
+KCalendarCore::DateList MultiAgendaView::selectedIncidenceDates() const
 {
-    KCalCore::DateList list;
+    KCalendarCore::DateList list;
     for (AgendaView *agendaView : qAsConst(d->mAgendaViews)) {
         list += agendaView->selectedIncidenceDates();
     }
@@ -484,7 +468,7 @@ AgendaView *MultiAgendaView::Private::createView(const QString &title)
 {
     QWidget *box = new QWidget(mTopBox);
     mTopBox->layout()->addWidget(box);
-    QVBoxLayout *layout = new QVBoxLayout(box);
+    auto *layout = new QVBoxLayout(box);
     layout->setContentsMargins(0, 0, 0, 0);
     layout->addWidget(new ElidedLabel(title));
     AgendaView *av = new AgendaView(q->preferences(),
@@ -590,7 +574,7 @@ void MultiAgendaView::resizeSplitters()
         return;
     }
 
-    QSplitter *lastMovedSplitter = qobject_cast<QSplitter *>(sender());
+    auto *lastMovedSplitter = qobject_cast<QSplitter *>(sender());
     if (!lastMovedSplitter) {
         lastMovedSplitter = d->mLeftSplitter;
     }
@@ -653,8 +637,8 @@ void MultiAgendaView::setChanges(Changes changes)
 
 void MultiAgendaView::setupScrollBar()
 {
-    if (!d->mAgendaViews.isEmpty() && d->mAgendaViews.first()->agenda()) {
-        QScrollBar *scrollBar = d->mAgendaViews.first()->agenda()->verticalScrollBar();
+    if (!d->mAgendaViews.isEmpty() && d->mAgendaViews.constFirst()->agenda()) {
+        QScrollBar *scrollBar = d->mAgendaViews.constFirst()->agenda()->verticalScrollBar();
         d->mScrollBar->setMinimum(scrollBar->minimum());
         d->mScrollBar->setMaximum(scrollBar->maximum());
         d->mScrollBar->setSingleStep(scrollBar->singleStep());
@@ -704,22 +688,22 @@ void MultiAgendaView::doRestoreConfig(const KConfigGroup &configGroup)
         d->mCollectionSelectionModels.resize(d->mCustomNumberOfColumns);
         for (int i = 0; i < d->mCustomNumberOfColumns; ++i) {
             // Sort the calanders by name
-            QSortFilterProxyModel *sortProxy = new QSortFilterProxyModel(this);
+            auto *sortProxy = new QSortFilterProxyModel(this);
             sortProxy->setDynamicSortFilter(true);
 
             sortProxy->setSourceModel(calendar()->entityTreeModel());
 
             // Only show the first column
-            KRearrangeColumnsProxyModel *columnFilterProxy = new KRearrangeColumnsProxyModel(this);
+            auto *columnFilterProxy = new KRearrangeColumnsProxyModel(this);
             columnFilterProxy->setSourceColumns(
                 QVector<int>() << Akonadi::ETMCalendar::CollectionTitle);
             columnFilterProxy->setSourceModel(sortProxy);
 
             // Keep track of selection.
-            QItemSelectionModel *qsm = new QItemSelectionModel(columnFilterProxy);
+            auto *qsm = new QItemSelectionModel(columnFilterProxy);
 
             // Make the model checkable.
-            KCheckableProxyModel *checkableProxy = new KCheckableProxyModel(this);
+            auto *checkableProxy = new KCheckableProxyModel(this);
             checkableProxy->setSourceModel(columnFilterProxy);
             checkableProxy->setSelectionModel(qsm);
             const QString groupName
