@@ -1,21 +1,9 @@
 /*
-  Copyright (c) 2007 Volker Krause <vkrause@kde.org>
-  Copyright (c) 2010 Klarälvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
-  Copyright (c) 2010 Andras Mantia <andras@kdab.com>
+  SPDX-FileCopyrightText: 2007 Volker Krause <vkrause@kde.org>
+  SPDX-FileCopyrightText: 2010 Klarälvdalens Datakonsult AB, a KDAB Group company <info@kdab.com>
+  SPDX-FileCopyrightText: 2010 Andras Mantia <andras@kdab.com>
 
-  This program is free software; you can redistribute it and/or modify
-  it under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful,
-  but WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-  GNU General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "timelineitem.h"
@@ -24,7 +12,6 @@
 
 #include <CalendarSupport/Utils>
 
-#include <KCalendarCore/Incidence>
 #include <KCalUtils/IncidenceFormatter>
 
 using namespace KCalendarCore;
@@ -38,7 +25,7 @@ TimelineItem::TimelineItem(const Akonadi::ETMCalendar::Ptr &calendar, uint index
     , mIndex(index)
 {
     mModel->removeRow(mIndex);
-    QStandardItem *dummyItem = new QStandardItem;
+    auto *dummyItem = new QStandardItem;
     dummyItem->setData(KGantt::TypeTask, KGantt::ItemTypeRole);
     mModel->insertRow(mIndex, dummyItem);
 }
@@ -67,7 +54,7 @@ void TimelineItem::insertIncidence(const Akonadi::Item &aitem, const QDateTime &
         }
     }
 
-    TimelineSubItem *item = new TimelineSubItem(mCalendar, aitem, this);
+    auto *item = new TimelineSubItem(mCalendar, aitem, this);
 
     item->setStartTime(start);
     item->setOriginalStart(start);
