@@ -1,18 +1,7 @@
 /*
-  Copyright (c) 2014-2018 Montel Laurent <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2020 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License, version 2, as
-  published by the Free Software Foundation.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: LGPL-2.0-or-later
 */
 
 #include "createcolorgui_test.h"
@@ -29,7 +18,7 @@
 CreateColorGui_test::CreateColorGui_test(QWidget *parent)
     : QWidget(parent)
 {
-    QVBoxLayout *vbox = new QVBoxLayout(this);
+    auto *vbox = new QVBoxLayout(this);
     mListWidget = new QListWidget;
     vbox->addWidget(mListWidget);
     createListWidgetItem();
@@ -44,10 +33,9 @@ void CreateColorGui_test::createListWidgetItem()
     EventViews::Prefs prefs;
     mListWidget->clear();
     for (int i = 0; i < 100; ++i) {
-        QListWidgetItem *item = new QListWidgetItem;
-        QColor defColor(0x37, 0x7A, 0xBC);
-        prefs.createNewColor(defColor, i);
-        item->setBackgroundColor(defColor);
+        auto *item = new QListWidgetItem;
+        QColor color = prefs.resourceColor(QString::number(i));
+        item->setBackground(color);
         mListWidget->addItem(item);
     }
 }
@@ -64,7 +52,7 @@ int main(int argc, char **argv)
     parser.process(app);
     aboutData.processCommandLine(&parser);
 
-    CreateColorGui_test *createColor = new CreateColorGui_test;
+    auto *createColor = new CreateColorGui_test;
     createColor->resize(800, 600);
     createColor->show();
 
